head	1.11;
access;
symbols
	pkgsrc-2013Q2:1.11.0.6
	pkgsrc-2013Q2-base:1.11
	pkgsrc-2012Q4:1.11.0.4
	pkgsrc-2012Q4-base:1.11
	pkgsrc-2011Q4:1.11.0.2
	pkgsrc-2011Q4-base:1.11
	pkgsrc-2011Q3:1.10.0.12
	pkgsrc-2011Q3-base:1.10
	pkgsrc-2011Q2:1.10.0.10
	pkgsrc-2011Q2-base:1.10
	pkgsrc-2011Q1:1.10.0.8
	pkgsrc-2011Q1-base:1.10
	pkgsrc-2010Q4:1.10.0.6
	pkgsrc-2010Q4-base:1.10
	pkgsrc-2010Q3:1.10.0.4
	pkgsrc-2010Q3-base:1.10
	pkgsrc-2010Q2:1.10.0.2
	pkgsrc-2010Q2-base:1.10
	pkgsrc-2009Q4:1.8.0.20
	pkgsrc-2009Q4-base:1.8
	pkgsrc-2008Q4:1.8.0.18
	pkgsrc-2008Q4-base:1.8
	pkgsrc-2008Q3:1.8.0.16
	pkgsrc-2008Q3-base:1.8
	cube-native-xorg:1.8.0.14
	cube-native-xorg-base:1.8
	pkgsrc-2008Q2:1.8.0.12
	pkgsrc-2008Q2-base:1.8
	pkgsrc-2008Q1:1.8.0.10
	pkgsrc-2008Q1-base:1.8
	pkgsrc-2007Q4:1.8.0.8
	pkgsrc-2007Q4-base:1.8
	pkgsrc-2007Q3:1.8.0.6
	pkgsrc-2007Q3-base:1.8
	pkgsrc-2007Q2:1.8.0.4
	pkgsrc-2007Q2-base:1.8
	pkgsrc-2007Q1:1.8.0.2
	pkgsrc-2007Q1-base:1.8
	pkgsrc-2006Q4:1.7.0.4
	pkgsrc-2006Q4-base:1.7
	pkgsrc-2006Q3:1.7.0.2
	pkgsrc-2006Q3-base:1.7
	pkgsrc-2006Q2:1.6.0.18
	pkgsrc-2006Q2-base:1.6
	pkgsrc-2006Q1:1.6.0.16
	pkgsrc-2006Q1-base:1.6
	pkgsrc-2005Q4:1.6.0.14
	pkgsrc-2005Q4-base:1.6
	pkgsrc-2005Q3:1.6.0.12
	pkgsrc-2005Q3-base:1.6
	pkgsrc-2005Q2:1.6.0.10
	pkgsrc-2005Q2-base:1.6
	pkgsrc-2005Q1:1.6.0.8
	pkgsrc-2005Q1-base:1.6
	pkgsrc-2004Q4:1.6.0.6
	pkgsrc-2004Q4-base:1.6
	pkgsrc-2004Q3:1.6.0.4
	pkgsrc-2004Q3-base:1.6
	pkgsrc-2004Q2:1.6.0.2
	pkgsrc-2004Q2-base:1.6
	pkgsrc-2004Q1:1.5.0.4
	pkgsrc-2004Q1-base:1.5
	pkgsrc-2003Q4:1.5.0.2
	pkgsrc-2003Q4-base:1.5
	buildlink2-base:1.2
	netbsd-1-4-PATCH002:1.1.1.1
	pkgsrc-base:1.1.1.1
	TNF:1.1.1;
locks; strict;
comment	@# @;


1.11
date	2011.11.13.21.06.31;	author sbd;	state dead;
branches;
next	1.10;

1.10
date	2010.06.09.09.01.43;	author sbd;	state Exp;
branches;
next	1.9;

1.9
date	2010.06.05.23.09.29;	author sbd;	state Exp;
branches;
next	1.8;

1.8
date	2007.03.14.12.29.05;	author markd;	state dead;
branches;
next	1.7;

1.7
date	2006.09.24.17.09.13;	author jdc;	state Exp;
branches;
next	1.6;

1.6
date	2004.05.17.10.40.45;	author jlam;	state dead;
branches;
next	1.5;

1.5
date	2003.05.28.02.34.01;	author jlam;	state Exp;
branches;
next	1.4;

1.4
date	2002.12.19.22.24.55;	author jlam;	state dead;
branches;
next	1.3;

1.3
date	2002.10.25.10.49.03;	author bouyer;	state Exp;
branches;
next	1.2;

1.2
date	2000.07.12.20.09.37;	author jlam;	state dead;
branches;
next	1.1;

1.1
date	99.11.29.02.18.54;	author jlam;	state Exp;
branches
	1.1.1.1;
next	;

1.1.1.1
date	99.11.29.02.18.54;	author jlam;	state Exp;
branches;
next	;


desc
@@


1.11
log
@Remove the usb-backend-both-usblp-and-libusb.dpatch as it is has been dropped
by it original author.
@
text
@$NetBSD: patch-am,v 1.10 2010/06/09 09:01:43 sbd Exp $

Incorporate
usb-backend-both-usblp-and-libusb.dpatch by  <till.kamppeter@@gmail.com>
http://www.cups.org/str.php?L3357

--- pdftops/GfxFont.cxx.dist	2004-02-02 22:41:09.000000000 +0000
+++ pdftops/GfxFont.cxx	2006-09-24 16:12:03.000000000 +0100
@@@@ -969,7 +969,11 @@@@
   if ((nameToGID = ff->getNameToGID())) {
     for (i = 0; i < 256; ++i) {
       if (!map[i] && (charName = enc[i])) {
-	map[i] = (Gushort)(int)nameToGID->lookup(charName);
d146 2
a147 2
+	 * Note that we are casting from "void *" here.
+	 * So, we must first cast to something at least as wide.
d149 47
a195 2
+	map[i] = (Gushort)(long)nameToGID->lookup(charName);
       }
d197 16
a212 1
     delete nameToGID;
@


1.7
log
@Make this compile on sparc64 with gcc 4.
(Need to cast to something at least as wide as "void *" - e.g. "long".)

OK wiz@@, joerg@@.
@
text
@d1 1
a1 1
$NetBSD$
@


1.6
log
@Correct the flags passed to the linker when building with libtool and bump
the PKGREVISION.  Also remove the unnecessary -preserve-dup-deps argument
to libtool, rename the configure option to --enable-libtool, and remove
the unnecessary bits to deal with libcrypt/libcrypto (buildlink3 does
this for us automatically).
@
text
@d1 1
a1 1
$NetBSD: patch-am,v 1.5 2003/05/28 02:34:01 jlam Exp $
d3 15
a17 20
--- config-scripts/cups-common.m4.orig	Wed May 14 14:24:38 2003
+++ config-scripts/cups-common.m4
@@@@ -81,8 +81,16 @@@@ dnl Architecture checks...
 AC_C_BIGENDIAN
 
 dnl Check for libraries...
-AC_SEARCH_LIBS(crypt, crypt)
 AC_SEARCH_LIBS(getspent, sec gen)
+
+dnl Check for crypt() in libcrypt.  We need to link -lcrypt ahead of any
+dnl OpenSSL libraries because the system crypt() is usually smarter than
+dnl the libcrypto crypt() routine.
+LIBCRYPT=""
+AC_CHECK_LIB(crypt, crypt, LIBCRYPT="-lcrypt", LIBS="$LIBS -lcrypt")
+EXPORT_LIBCRYPT="$LIBCRYPT"
+AC_SUBST(LIBCRYPT)
+AC_SUBST(EXPORT_LIBCRYPT)
 
 LIBMALLOC=""
 AC_ARG_ENABLE(mallinfo, [  --enable-mallinfo       turn on malloc debug information, default=no])
@


1.5
log
@Update print/cups to 1.1.19.  Major changes from version 1.1.18nb2 include:

- security fix to scheduler to address a DoS attack
- improve conformance to IPP specification
- miscellaneous bug fixes to server and userland utilities
- plug memory leaks
- bug fixes to SSL code
- the mime.convs file was missing the filter definition for Windows BMP
  (image/x-bitmap) files
- improved test suite
- added CUPS support files for Java, Perl, and PHP
- The cups-lpd mini-daemon now sends jobs to the default queue when an
  empty queue name (or "lp" and there is no "lp" queue) is sent.
- The scheduler now supports fax queues identified by a "*cupsFax: True"
  attribute in the PPD file.
- The scheduler now supports print files that have been compressed using
  gzip.
- Added a robots.txt file to the standard install to prevent search
  engines from indexing the CUPS server.
- When writing BSD printcap files, the scheduler now includes the rm and
  rp attributes, allowing the file to be exported to LPD clients.
- The pdftops filter now scales PDF pages within the printable area of the
  page.
- The PostScript filter now supports binary PostScript files and files
  beginning with the PJL language escape sequence.
- Fixed the CIE colorspace support code in the image and PS RIPs.
@
text
@d1 1
a1 1
$NetBSD$
@


1.4
log
@Updated print/cups to 1.1.17.  Changes from version 1.1.16 include:

- Bug fixes to the backends and scheduler.
- Bug fixes to the image filters.
- The scheduler now allows accounts authenticated via PAM to not have a
  corresponding UNIX account, but group membership still requires the
  account name to be listed in the UNIX group file(s)...
- Added some startup performance enhancements to the scheduler so that the
  printer object information is regenerated fewer times and the MIME type
  database is not filled with lots of empty filters for raw/direct queues.
- The backends now ignore SIGPIPE so that failed job filters will not stop
  a print queue.
- User-defined classification strings are now printed verbatim.
- The lpstat command did not allow for destination lists.
- The LPD backend now sends the job title as the print filename.
- Added support for variable sizes in the EPSON dot matrix printer drivers.
  This allows for pages as short as 1/2" (1 row of labels) and does not do
  an automatic form feed.
- The Solaris USB backend now supports the new device URI syntax.
- The serial backend now enumerates serial ports under MacOS X.
@
text
@d1 1
a1 1
$NetBSD: patch-am,v 1.3 2002/10/25 10:49:03 bouyer Exp $
d3 4
a6 12
--- configure.orig	Mon Oct  7 17:40:29 2002
+++ configure	Fri Oct 25 12:23:54 2002
@@@@ -5963,9 +5963,9 @@@@
 	*)
 		# All others
 		INSTALL_SYSV="install-sysv"
-		CUPS_SERVERBIN="$exec_prefix/lib/cups"
+		CUPS_SERVERBIN="$exec_prefix/libexec/cups"
 		cat >>confdefs.h <<_ACEOF
-#define CUPS_SERVERBIN "$exec_prefix/lib/cups"
+#define CUPS_SERVERBIN "$exec_prefix/libexec/cups"
 _ACEOF
d8 15
a22 20
 		;;
@@@@ -6085,12 +6085,12 @@@@
 		;;
 	SunOS* | HP-UX*)
 		# Solaris and HP-UX
-		CAT1EXT=1
-		CAT3EXT=3
-		CAT5EXT=5
-		CAT8EXT=1m
-		MAN8EXT=1m
-		MAN8DIR=1m
+		CAT1EXT=0
+		CAT3EXT=0
+		CAT5EXT=0
+		CAT8EXT=0
+		MAN8EXT=8
+		MAN8DIR=8
 		;;
 	*)
 		# All others
@


1.3
log
@Make CUPS_SERVERBIN points to $PREFIX/libexec/cups for solaris too
Correct man extentions for solaris.
Use ${PKGLOCALEDIR} in PLIST for locale directories.
@
text
@d1 1
a1 1
$NetBSD: $
@


1.2
log
@Update CUPS to 1.1.  Remove most of the patches; I worked closely with
the author to make this package compile more seamlessly on BSD systems,
and in particular with the NetBSD pkgsrc software collection.

CUPS 1.1 is the newest production (stable) release of CUPS.  It
provides many new features from the 1.0.x releases, including a
new Level 3 PostScript RIP, a new PDF filter, EPSON printer
drivers, IPP/1.1 support, banner page support, and LPD client
support.  Binaries for several platforms are also available.

Major changes in v1.1 include:

	- The text filter now embeds missing fonts.
	- Integrated Xpdf's pdftops filter into CUPS, which is a
	  lightweight and reliable replacement for Ghostscript's
	  PDF support.
	- The web administration interface now allows you to set
	  the default banner pages.
	- Images can now be positioned on the page using the new
	  "position" option.
	- Updated the serial, parallel, and usb backends to do
	  multiple writes and ignore ioctl() errors as needed;
	  this should fix problems with serial printing on old
	  serial drivers and with the UltraSPARC parallel port
	  driver under Solaris 2.7.
	- Now propagate LD_LIBRARY_PATH to child processes from
	  cupsd.
	- Queued remote jobs recreate remote printers as needed
	  when the scheduler is started.
	- Deleting a printer also purges all jobs on that
	  printer.
	- Old job and control files that don't belong to a
	  printer are automatically deleted.
	- cups-lpd now supports options set with lpoptions.
	- The IPP backend now switches to IPP/1.0 if a 1.1
	  request fails.
@
text
@d1 1
a1 1
$NetBSD: patch-am,v 1.1 1999/11/29 02:18:54 jlam Exp $
d3 12
a14 4
--- doc/Makefile.orig	Wed Sep 22 16:06:17 1999
+++ doc/Makefile	Sun Nov 28 21:06:28 1999
@@@@ -71,14 +71,14 @@@@
 #
d16 20
a35 20
 install:
-	-$(MKDIR) $(DATADIR)/doc
-	$(CP) $(WEBPAGES) $(DATADIR)/doc
-	$(CP) overview.html overview.pdf $(DATADIR)/doc
-	$(CP) $(DOCUMENTS:.shtml=.html) $(DATADIR)/doc
-	$(CP) $(DOCUMENTS:.shtml=.pdf) $(DATADIR)/doc
-	-$(MKDIR) $(DATADIR)/doc/images
-	$(CP) $(WEBIMAGES) $(DATADIR)/doc/images
-	$(CP) $(DOCIMAGES) $(DATADIR)/doc/images
+	-$(BSD_INSTALL_DATA_DIR) $(DOCDIR)
+	$(BSD_INSTALL_DATA) $(WEBPAGES) $(DOCDIR)
+	$(BSD_INSTALL_DATA) overview.html overview.pdf $(DOCDIR)
+	$(BSD_INSTALL_DATA) $(DOCUMENTS:.shtml=.html) $(DOCDIR)
+	$(BSD_INSTALL_DATA) $(DOCUMENTS:.shtml=.pdf) $(DOCDIR)
+	-$(BSD_INSTALL_DATA_DIR) $(DOCDIR)/images
+	$(BSD_INSTALL_DATA) $(WEBIMAGES) $(DOCDIR)/images
+	$(BSD_INSTALL_DATA) $(DOCIMAGES) $(DOCDIR)/images
 
 #
 # The overview, admin guide, and user's guide get special attention...
@


1.1
log
@Initial revision
@
text
@d1 1
a1 1
$NetBSD$
@


1.1.1.1
log
@Common UNIX Printing System, a IPP 1.0 implementation.
@
text
@@

--- backend/usb-unix.c.orig	2009-12-08 02:13:42.000000000 +0000
+++ backend/usb-unix.c
@@@@ -26,4 +26,14 @@@@
 
 /*
+ *   If USB_HYBRID is define append "_unix" to functions.
+ */
+#ifdef USB_HYBRID
+# define print_device	print_device_unix
+# define list_devices	list_devices_unix
+# define open_device	open_device_unix
+# define side_cb	side_cb_unix
+#endif
+
+/*
  * Include necessary headers.
  */
@@@@ -133,4 +143,8 @@@@ print_device(const char *uri,		/* I - De
 	sleep(10);
       }
+#ifdef HAVE_USB_H
+      else
+	return (-1);
+#else
       else if (errno == ENXIO || errno == EIO || errno == ENOENT ||
                errno == ENODEV)
@@@@ -148,4 +162,5 @@@@ print_device(const char *uri,		/* I - De
 	return (CUPS_BACKEND_FAILED);
       }
+#endif
     }
   }
@@@@ -358,6 +373,8 @@@@ open_device(const char *uri,		/* I - Dev
 		device_id[1024],	/* Device ID string */
 		make_model[1024],	/* Make and model */
-		device_uri[1024];	/* Device URI string */
-
+		device_uri[1024],	/* Device URI string */
+		requested_uri[1024],	/* Device URI string */
+		*str1,
+		*str2;
 
    /*
@@@@ -408,5 +425,53 @@@@ open_device(const char *uri,		/* I - Dev
         }
 
-        if (!strcmp(uri, device_uri))
+	/* Work on a copy of uri */
+	strncpy(requested_uri, uri, sizeof(requested_uri));
+	requested_uri[sizeof(requested_uri) - 1] = '\0';
+
+	/*
+	 * libusb-discovered URIs can have an "interface" specification and this
+	 * never happens for usblp-discovered URIs, so remove the "interface"
+	 * specification from the URI of the print queue. This way a queue for
+	 * a libusb-discovered printer can now be accessed via the usblip kernel
+	 * module
+	 */
+	if ((str1 = strstr(requested_uri, "interface=")) != NULL)
+	  *(str1 - 1) = '\0';
+
+	/*
+	 * Old URI with "serial=?". Cut this part off and consider this as
+	 * an URI without serial number
+	 */
+	if ((str1 = strstr(requested_uri, "serial=?")) != NULL)
+	 *(str1 - 1) = '\0';
+
+	/*
+	 * Old URI without serial number. Match it also with URIs with serial
+	 * number
+	 */
+	if (((str1 = strstr(requested_uri, "serial=")) == NULL) &&
+	    ((str2 = strstr(device_uri, "serial=")) != NULL))
+	    *(str2 - 1) = '\0';
+
+	/*
+	 * libusb-discovered URIs can have a "serial" specification when the
+	 * usblp-discovered URI for the same printer does not have one, as
+	 * with libusb we can discover serial numbers also with other methods
+	 * than only via the device ID. Therefore we accept also a
+	 * usblp-discovered printer without serial number as a match. This we
+	 * do by removing the serial number from the queue's (libusb-discovered)
+	 * URI before comparing. Also warn the user because of the incapability
+	 * of the usblp-based access to distinguish printers by the serial
+	 * number.
+	 */
+	if (((str1 = strstr(requested_uri, "serial=")) != NULL) &&
+	    ((str2 = strstr(device_uri, "serial=")) == NULL))
+	{
+	  *(str1 - 1) = '\0';
+	  fprintf(stderr, "WARNING: If you have more than one %s printer connected to this machine, please unload (and blacklist) the \"usblp\" kernel module as otherwise CUPS will not be able to distinguish your printers.\n",
+		  make_model);
+	}
+
+        if (!strcmp(requested_uri, device_uri))
 	{
 	 /*
@@@@ -434,8 +499,12 @@@@ open_device(const char *uri,		/* I - Dev
 
       if (busy)
+      {
 	_cupsLangPuts(stderr,
 	              _("INFO: Printer busy; will retry in 5 seconds...\n"));
 
-      sleep(5);
+	sleep(5);
+      }
+      else
+	return -1;
     }
   }
@@@@ -626,4 +695,8 @@@@ side_cb(int         print_fd,		/* I - Pr
 }
 
+#undef print_device
+#undef list_devices
+#undef open_device
+#undef side_cb
 
 /*
@


1.10
log
@The usb-backend-both-usblp-and-libusb.dpatch does not make an allowance for
"--disable-libusb", fix that!

Bump PKGREVISION.
@
text
@d1 1
a1 1
$NetBSD: patch-am,v 1.9 2010/06/05 23:09:29 sbd Exp $
@


1.9
log
@Incorporate:

usb-backend-both-usblp-and-libusb.dpatch by  <till.kamppeter@@gmail.com>

http://www.cups.org/str.php?L3357
One "usb" CUPS backend for both libusb-based and usblp-based access.

Bump PKGREVISION.
@
text
@d1 1
a1 1
$NetBSD$
d9 1
a9 13
@@@@ -18,10 +18,10 @@@@
  *
  * Contents:
  *
  *   print_device() - Print a file to a USB device.
  *   list_devices() - List all USB devices.
  *   open_device()  - Open a USB device...
  *   side_cb()      - Handle side-channel requests...
  */
d12 11
a22 2
@@@@ -35,17 +35,17 @@@@
  * Local functions...
d24 1
a24 30
 
-static int	open_device(const char *uri, int *use_bc);
-static int	side_cb(int print_fd, int device_fd, int snmp_fd,
+static int	open_device_unix(const char *uri, int *use_bc);
+static int	side_cb_unix(int print_fd, int device_fd, int snmp_fd,
 		        http_addr_t *addr, int use_bc);
 
 
 /*
  * 'print_device()' - Print a file to a USB device.
  */
 
 int					/* O - Exit status */
-print_device(const char *uri,		/* I - Device URI */
+print_device_unix(const char *uri,		/* I - Device URI */
              const char *hostname,	/* I - Hostname/manufacturer */
              const char *resource,	/* I - Resource/modelname */
 	     char       *options,	/* I - Device options/serial number */
@@@@ -102,7 +102,7 @@@@ print_device(const char *uri,		/* I - De
              strncasecmp(hostname, "Minolta", 7);
 #endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ || __DragonFly__ */
 
-    if ((device_fd = open_device(uri, &use_bc)) == -1)
+    if ((device_fd = open_device_unix(uri, &use_bc)) == -1)
     {
       if (getenv("CLASS") != NULL)
       {
@@@@ -132,6 +132,10 @@@@ print_device(const char *uri,		/* I - De
 	              _("INFO: Printer busy; will retry in 10 seconds...\n"));
d33 1
a33 3
       {
@@@@ -147,6 +151,7 @@@@ print_device(const char *uri,		/* I - De
 			resource, strerror(errno));
d39 1
a39 40
   while (device_fd < 0);
@@@@ -190,7 +195,7 @@@@ print_device(const char *uri,		/* I - De
     tbytes = backendRunLoop(print_fd, device_fd, -1, NULL, use_bc, 1, NULL);
 
 #else
-    tbytes = backendRunLoop(print_fd, device_fd, -1, NULL, use_bc, 1, side_cb);
+    tbytes = backendRunLoop(print_fd, device_fd, -1, NULL, use_bc, 1, side_cb_unix);
 #endif /* __sun */
 
     if (print_fd != 0 && tbytes >= 0)
@@@@ -214,11 +219,11 @@@@ print_device(const char *uri,		/* I - De
 
 
 /*
  * 'list_devices()' - List all USB devices.
  */
 
 void
-list_devices(void)
+list_devices_unix(void)
 {
 #ifdef __linux
   int	i;				/* Looping var */
@@@@ -320,11 +325,11 @@@@ list_devices(void)
 
 
 /*
  * 'open_device()' - Open a USB device...
  */
 
 static int				/* O - File descriptor or -1 on error */
-open_device(const char *uri,		/* I - Device URI */
+open_device_unix(const char *uri,		/* I - Device URI */
             int        *use_bc)		/* O - Set to 0 for unidirectional */
 {
   int	fd;				/* File descriptor */
@@@@ -357,9 +362,12 @@@@ open_device(const char *uri,		/* I - Dev
     char	device[255],		/* Device filename */
a48 1
+    
d50 1
a50 4
     * Find the correct USB device...
     */
@@@@ -407,7 +415,55 @@@@ open_device(const char *uri,		/* I - Dev
 	  device_uri[0] = '\0';
d105 1
a105 3
 	  * Yes, return this file descriptor...
@@@@ -433,10 +489,14 @@@@ open_device(const char *uri,		/* I - Dev
       */
d119 2
a120 2
 #elif defined(__sun) && defined(ECPPIOC_GETDEVID)
@@@@ -557,11 +617,11 @@@@ open_device(const char *uri,		/* I - Dev
d122 4
a127 10
- * 'side_cb()' - Handle side-channel requests...
+ * 'side_cb_unix()' - Handle side-channel requests...
  */
 
 static int				/* O - 0 on success, -1 on error */
-side_cb(int         print_fd,		/* I - Print file */
+side_cb_unix(int         print_fd,		/* I - Print file */
         int         device_fd,		/* I - Device file */
         int         snmp_fd,		/* I - SNMP socket (unused) */
 	http_addr_t *addr,		/* I - Device address (unused) */
@


1.8
log
@Update cups to 1.2.8

ok'ed jlam a while back.

CUPS 1.2.8 adds a French localization, updates the Japanese and Spanish
localizations, and fixes several web interface, printing, and networking
bugs.

CUPS 1.2.7 adds several Mac OS X improvements, implements timeouts in the
SSL negotiation code, and fixes the bounding box generated by the PostScript
filter, bidirectional support in the USB backend, and another case where the
lpstat command could hang.

CUPS 1.2.6 fixes some compile errors, localization of the web interface on
Mac OS X, bugs in the lpc and lpstat commands, and backchannel support in
the parallel backend.

CUPS 1.2.5 fixes minor printing, networking, and documentation issues and
adds support for older versions of DBUS and a translation for Estonian.

CUPS 1.2.4 fixes a number of web interface, scheduler, and CUPS API
issues.

CUPS 1.2.3 fixes a number of web interface, networking, remote printing,
and CUPS API issues.

CUPS 1.2.2 fixes several build, platform, notification, and printing bugs.

CUPS 1.2.1 fixes several build, platform, and printing bugs.

CUPS 1.2.0 is the first stable feature release in the 1.2.x series and
includes over 90 new features and changes since CUPS 1.1.23, including a
greatly improved web interface and "plug-and-print" support for many local
and network printers.
@
text
@d1 1
@@@@ -18,10 +18,10 @@@@
  * Contents:
  *
- *   print_device() - Print a file to a USB device.
- *   list_devices() - List all USB devices.
- *   open_device()  - Open a USB device...
- *   side_cb()      - Handle side-channel requests...
+ *   print_device_unix() - Print a file to a USB device.
+ *   list_devices_unix() - List all USB devices.
+ *   open_device_unix()  - Open a USB device...
+ *   side_cb_unix()      - Handle side-channel requests...
  */
d12 11
@@@@ -35,17 +35,17 @@@@
 
 /*
- * 'print_device()' - Print a file to a USB device.
+ * 'print_device_unix()' - Print a file to a USB device.
  */
 
@@@@ -214,11 +219,11 @@@@ print_device(const char *uri,		/* I - De
 
 /*
- * 'list_devices()' - List all USB devices.
+ * 'list_devices_unix()' - List all USB devices.
  */
 
@@@@ -320,11 +325,11 @@@@ list_devices(void)
 
 /*
- * 'open_device()' - Open a USB device...
+ * 'open_device_unix()' - Open a USB device...
  */
 
a1 1
$NetBSD: patch-am,v 1.7 2006/09/24 17:09:13 jdc Exp $
d3 142
a144 7